@@ -41,12 +41,13 @@ from contextlib import suppress
 from typing import Awaitable, Optional, Union
 
 import aio_pika
-from aiormq import ChannelInvalidStateError
+from aio_pika.exceptions import ChannelInvalidStateError
 from yarl import URL
 
 from .connection_watchdog import ConnectionWatchdog
 from .logging import get_logger
 from .rpc import RPCDispatcher
+from .version import __version__
 
 logger = get_logger(__name__)
 timer = time.monotonic
@@ -98,13 +99,13 @@ class Agent(RPCDispatcher):
     LOG_MAX_WIDTH = 200
 
     def __init__(
-            self,
-            token,
-            management_url,
-            *,
-            connection_timeout: Union[int, float] = 60,
-            event_loop=None,
-            add_uuid=False,
+        self,
+        token,
+        management_url,
+        *,
+        connection_timeout: Union[int, float] = 60,
+        event_loop=None,
+        add_uuid=False,
     ):
         self.token = f"{token}.{uuid.uuid4().hex}" if add_uuid else token
 
@@ -135,17 +136,23 @@ class Agent(RPCDispatcher):
         self._management_exchange = None
 
         self._rpc_response_handlers = dict()
-        logger.debug("Initialized Agent")
+        logger.info(
+            "Initialized Agent `{}` (running version `metricq=={}`)",
+            type(self).__qualname__,
+            __version__,
+        )
 
     def derive_address(self, address: str):
         """ Add the credentials from the management connection to the provided address """
         management_obj = URL(self._management_url)
         vhost_prefix = "vhost:"
         if address.startswith(vhost_prefix):
-            derived_obj = management_obj.with_path(address[len(vhost_prefix):])
+            derived_obj = management_obj.with_path(address[len(vhost_prefix) :])
         else:
             address_obj = URL(address)
-            derived_obj = address_obj.with_user(management_obj.user).with_password(management_obj.password)
+            derived_obj = address_obj.with_user(management_obj.user).with_password(
+                management_obj.password
+            )
         return str(derived_obj)
 
     @property
@@ -209,7 +216,7 @@ class Agent(RPCDispatcher):
         self._management_connection_watchdog.set_established()
 
     def run(
-            self, catch_signals=("SIGINT", "SIGTERM"), cancel_on_exception=False
+        self, catch_signals=("SIGINT", "SIGTERM"), cancel_on_exception=False
     ) -> None:
         """Run an Agent by calling :py:meth:`connect` and waiting for it to be
         :py:meth:`stop`ped.
@@ -284,13 +291,13 @@ class Agent(RPCDispatcher):
             logger.debug("Event loop completed, exiting...")
 
     async def rpc(
-            self,
-            exchange: aio_pika.Exchange,
-            routing_key: str,
-            response_callback=None,
-            timeout=60,
-            cleanup_on_response=True,
-            **kwargs,
+        self,
+        exchange: aio_pika.Exchange,
+        routing_key: str,
+        response_callback=None,
+        timeout=60,
+        cleanup_on_response=True,
+        **kwargs,
     ):
         """
         :param function: tag of the RPC
@@ -400,9 +407,7 @@ class Agent(RPCDispatcher):
             exception=None if signal == "SIGINT" else ReceivedSignalError(signal)
         )
 
-    def on_exception(
-            self, loop: asyncio.AbstractEventLoop, context
-    ):
+    def on_exception(self, loop: asyncio.AbstractEventLoop, context):
         logger.error("Exception in event loop: {}".format(context["message"]))
 
         with suppress(KeyError):
@@ -428,9 +433,9 @@ class Agent(RPCDispatcher):
                 )
 
     def _schedule_stop(
-            self,
-            exception: Optional[Exception] = None,
-            loop: asyncio.AbstractEventLoop = None,
+        self,
+        exception: Optional[Exception] = None,
+        loop: asyncio.AbstractEventLoop = None,
     ):
         loop = self.event_loop if loop is None else loop
         loop.create_task(self.stop(exception=exception))
